import os
from autopilot.testcase import AutopilotTestCase
from autopilot.matchers import Eventually
from testtools.matchers import Equals, Contains, NotEquals
from autopilot.input import Mouse, Touch, Pointer


class EogTests(AutopilotTestCase):

    def setUp(self):
        super(EogTests, self).setUp()

        image_name = 'logo-ubuntu_su-orange-hex.jpg'
        for root, dirs, files in os.walk(os.getcwd()):
            for name in files:
                if name == image_name:
                    img_path = os.path.abspath(os.path.join(root, name))
        #Lets auto load the image as we dn't have access to the global menu
        self.app = self.launch_test_application('eog', img_path)

        self.pointing_device = Pointer(Mouse.create())
        self.get_eog_objects()

    def test_display_image(self):
        #check that the image loaded
        self.assertThat(self.eog_window.title,
                        Eventually(Contains('logo-ubuntu_su-orange-hex.jpg')))

    def test_zoom_image(self):
        self.pointing_device.move_to_object(self.normal_size_button)
        self.pointing_device.click()
        self.assertThat(self.status_label.label, Eventually(Contains('100%')))

        self.pointing_device.move_to_object(self.zoom_in_button)
        self.pointing_device.click()
        self.assertThat(self.status_label.label, Eventually(Contains('200%')))

        self.pointing_device.move_to_object(self.zoom_out_button)
        self.pointing_device.click()
        self.assertThat(self.status_label.label, Eventually(Contains('100%')))

    def test_show_prev_and_next_images(self):

        self.pointing_device.move_to_object(self.previous_button)
        self.pointing_device.click()
        self.assertThat(self.eog_window.title,
                        Eventually(Contains(
                            'logo-ubuntu_st_no-white_orangecof-hex')))
        self.pointing_device.click()
        self.assertThat(self.eog_window.title,
                        Eventually(Contains(
                            'logo-ubuntu_st_no-black_orange-hex')))

        self.pointing_device.click()
        self.assertThat(self.eog_window.title,
                        Eventually(Contains(
                            'logo-ubuntu_cof-orange-hex')))
        #test we can go forward
        self.pointing_device.move_to_object(self.next_button)
        self.pointing_device.click()
        self.assertThat(self.eog_window.title,
                        Eventually(Contains(
                            'logo-ubuntu_st_no-black_orange-hex')))
        self.pointing_device.click()
        self.assertThat(self.eog_window.title,
                        Eventually(Contains(
                            'logo-ubuntu_st_no-white_orangecof-hex')))
        self.pointing_device.click()
        self.assertThat(self.eog_window.title,
                        Eventually(Contains(
                            'logo-ubuntu_su-orange-hex.jpg')))

    def test_rotate_image(self):
        self.pointing_device.move_to_object(self.normal_size_button)
        self.assertThat(self.status_label.label, Contains('64 pixels'))

        self.pointing_device.move_to_object(self.rotate_left_button)
        self.pointing_device.click()

        self.assertThat(self.status_label.label,
                        Eventually(Contains('284 pixels')))

        self.pointing_device.move_to_object(self.rotate_right_button)
        self.pointing_device.click()

        self.assertThat(self.status_label.label,
                        Eventually(Contains('64 pixels')))

    def get_eog_objects(self):
        #----------------------------------------------------------------#
        #             EOG WINDOW OBJECT                                  #
        #                                                                #
        self.eog_window = self.app.select_single('EogWindow')
        #----------------------------------------------------------------#
        #             EOG TOOLBAR OBJECTS                                #
        #                                                                #
        self.eog_toolbar = self.eog_window.select_single('EggEditableToolbar')
        self.previous_button = self.eog_toolbar.select_single(
            'GtkLabel', label='Previous')
        self.next_button = self.eog_toolbar.select_single(
            'GtkLabel', label='Next')
        self.zoom_in_button = self.eog_toolbar.select_single(
            'GtkToolButton', label='In')
        self.zoom_out_button = self.eog_toolbar.select_single(
            'GtkToolButton', label='Out')
        self.normal_size_button = self.eog_toolbar.select_single(
            'GtkToolButton', label='Normal')
        self.fit_window_button = self.eog_toolbar.select_single(
            'GtkToolButton', label='Fit')
        self.rotate_left_button = self.eog_toolbar.select_single(
            'GtkToolButton', label='Left')
        self.rotate_right_button = self.eog_toolbar.select_single(
            'GtkToolButton', label='Right')

        #-----------------------------------------------------------------#
        #           EOG STATUS BAR OBJECTS                                #
        #                                                                 #
        self.eog_statusbar = self.eog_window.select_single('EogStatusbar')
        self.statusbar_frame = self.eog_statusbar.select_single('GtkFrame')
        self.status_label = self.statusbar_frame.select_single('GtkLabel')
